@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "musicsettings.h"
 
@@ -41,7 +25,7 @@ MusicSettings::MusicSettings(QObject *parent) :
 
 MusicSettings::~MusicSettings()
 {
-
+    release();
 }
 
 void MusicSettings::init()
@@ -52,6 +36,15 @@ void MusicSettings::init()
     m_settings->setBackend(backend);
 }
 
+void MusicSettings::release()
+{
+    if (!m_settings.isNull()) {
+        m_settings->sync();
+        delete m_settings;
+        m_settings = nullptr;
+    }
+}
+
 QPointer<Dtk::Core::DSettings> MusicSettings::settings()
 {
     return m_settings;
@@ -59,15 +52,17 @@ QPointer<Dtk::Core::DSettings> MusicSettings::settings()
 
 void MusicSettings::sync()
 {
-    m_settings->sync();
+    if (!m_settings.isNull())
+        m_settings->sync();
 }
 
 QVariant MusicSettings::value(const QString &key)
 {
-    return m_settings->value(key);
+    return m_settings.isNull() ? QVariant() : m_settings->value(key);
 }
 
 void MusicSettings::setOption(const QString &key, const QVariant &value)
 {
-    m_settings->setOption(key, value);
+    if (!m_settings.isNull())
+        m_settings->setOption(key, value);
 }
