@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "player.h"
 
@@ -64,8 +48,10 @@
 #include <DPushButton>
 #include <DPalette>
 #include <QThread>
+#include "../util/eventlogutils.h"
 
 #include "commonservice.h"
+#include "config.h"
 
 DCORE_USE_NAMESPACE
 
@@ -273,6 +259,14 @@ void Player::playMeta(MediaMeta meta)
         //设置音乐播放
         emit signalPlaybackStatusChanged(Player::Paused);
     }
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::StartPlaying},
+        {"version", VERSION},
+        {"successful", true},
+        {"encapsulation_format", meta.filetype}//封装格式
+    };
+    EventLogUtils::get().writeLogs(obj);
 }
 
 void Player::resume()
@@ -448,7 +442,7 @@ void Player::playNextMeta(bool isAuto)
             }
             if (index != -1) {
                 for (int i = 0; i < curMetaList.size(); i++) {
-                    if (curMetaList.at(i).first > index && i >= 0) {
+                    if (curMetaList.at(i).first > index) {
                         index = i - 1;
                         break;
                     }
@@ -998,7 +992,7 @@ void Player::setEqualizerbauds(int index, int val)
 void Player::setEqualizerCurMode(int curIndex)
 {
     //非自定义模式时
-    if (curIndex != 0) {
+    if (curIndex > 0) {
         m_basePlayer->loadFromPreset(uint(curIndex - 1));
         //设置放大值
         m_basePlayer->setPreamplification(m_basePlayer->preamplification());
@@ -1006,6 +1000,13 @@ void Player::setEqualizerCurMode(int curIndex)
             //设置频率值
             m_basePlayer->setAmplificationForBandAt(m_basePlayer->amplificationForBandAt(uint(i)), uint(i));
         }
+    } else if (curIndex == -1) { // 关闭均衡器时
+        //设置放大值
+        m_basePlayer->setPreamplification(12);
+        for (int i = 0 ; i < 10; i++) {
+            //设置频率值
+            m_basePlayer->setAmplificationForBandAt(uint(0), uint(i));
+        }
     }
 }
 
