@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <vlc/vlc.h>
 #include <vlc_common.h>
@@ -77,6 +61,11 @@ typedef void (*config_PutInt_func)(vlc_object_t *, const char *, int64_t);
 
 typedef int (*var_SetChecked_func)(vlc_object_t *, const char *, int, vlc_value_t);
 
+typedef int (*vlc_audio_set_volume_function)(libvlc_media_player_t *, int);
+typedef int (*vlc_audio_get_volume_function)(libvlc_media_player_t *);
+typedef int (*vlc_audio_set_mute_function)(libvlc_media_player_t *, int);
+typedef int (*vlc_audio_get_mute_function)(libvlc_media_player_t *);
+
 VlcMediaPlayer::VlcMediaPlayer(VlcInstance *instance)
     : QObject(instance)
 {
@@ -205,7 +194,7 @@ int VlcMediaPlayer::length() const
 void VlcMediaPlayer::open(VlcMedia *media)
 {
     //防止没打开文件
-    if(media->core() == nullptr)
+    if (media->core() == nullptr)
         return;
     vlc_media_player_set_media_function vlc_media_player_set_media = (vlc_media_player_set_media_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_media_player_set_media");
     config_PutInt_func config_PutInt_fc = (config_PutInt_func)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("config_PutInt");
@@ -287,6 +276,26 @@ void VlcMediaPlayer::setTime(qint64 time)
     VlcError::showErrmsg();
 }
 
+void VlcMediaPlayer::setVolume(int volume)
+{
+    if (!_vlcMediaPlayer)
+        return;
+    vlc_audio_set_volume_function vlc_audio_set_volume = (vlc_audio_set_volume_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_audio_set_volume");
+    vlc_audio_set_volume(_vlcMediaPlayer, volume);
+
+    VlcError::showErrmsg();
+}
+
+void VlcMediaPlayer::setMute(bool mute)
+{
+    if (!_vlcMediaPlayer)
+        return;
+    vlc_audio_set_mute_function vlc_audio_set_mute = (vlc_audio_set_mute_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_audio_set_mute");
+    vlc_audio_set_mute(_vlcMediaPlayer, mute ? 1 : 0);
+
+    VlcError::showErrmsg();
+}
+
 Vlc::State VlcMediaPlayer::state() const
 {
     // It's possible that the vlc doesn't play anything
@@ -361,9 +370,9 @@ void VlcMediaPlayer::libvlc_callback(const libvlc_event_t *event,
     case libvlc_MediaPlayerEncounteredError:
         emit core->error();
         break;
-    case libvlc_MediaPlayerTimeChanged:
-        emit core->timeChanged(event->u.media_player_time_changed.new_time);
-        break;
+//    case libvlc_MediaPlayerTimeChanged:
+//        emit core->timeChanged(event->u.media_player_time_changed.new_time);
+//        break;
     case libvlc_MediaPlayerPositionChanged:
         emit core->positionChanged(event->u.media_player_position_changed.new_position);
         break;
@@ -403,6 +412,22 @@ float VlcMediaPlayer::position()
     return vlc_media_player_get_position(_vlcMediaPlayer);
 }
 
+int VlcMediaPlayer::getVolume()
+{
+    if (!_vlcMediaPlayer)
+        return -1;
+    vlc_audio_get_volume_function vlc_audio_get_volume = (vlc_audio_get_volume_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_audio_get_volume");
+    return vlc_audio_get_volume(_vlcMediaPlayer);
+}
+
+bool VlcMediaPlayer::getMute()
+{
+    if (!_vlcMediaPlayer)
+        return -1;
+    vlc_audio_get_mute_function vlc_audio_get_mute = (vlc_audio_get_mute_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_audio_get_mute");
+    return vlc_audio_get_mute(_vlcMediaPlayer) > 0 ? true : false;
+}
+
 void VlcMediaPlayer::setPosition(float pos)
 {
     vlc_media_player_set_position_function vlc_media_player_set_position = (vlc_media_player_set_position_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_media_player_set_position");
