@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef VLCQT_MEDIAPLAYER_H_
 #define VLCQT_MEDIAPLAYER_H_
@@ -102,6 +86,27 @@ public slots:
     */
     void setTime(qint64 time);
 
+    /**
+     * Set current software audio volume.
+     *
+     * \param i_volume the volume in percents (0 = mute, 100 = 0dB)
+     * \return 0 if the volume was set, -1 if it was out of range
+     */
+    void setVolume(int volume);
+
+    /**
+     * Set mute status.
+     *
+     * \param status If status is true then mute, otherwise unmute
+     * \warning This function does not always work. If there are no active audio
+     * playback stream, the mute status might not be available. If digital
+     * pass-through (S/PDIF, HDMI...) is in use, muting may be unapplicable. Also
+     * some audio output plugins do not support muting at all.
+     * \note To force silent playback, disable all audio tracks. This is more
+     * efficient and reliable than mute.
+     */
+    void setMute(bool mute);
+
 public:
     /*!
         \brief Get the current movie time (in ms).
@@ -121,6 +126,21 @@ public:
     */
     float position();
 
+    /**
+     * Get current software audio volume.
+     *
+     * \return the software volume in percents
+     * (0 = mute, 100 = nominal / 0dB)
+     */
+    int getVolume();
+
+    /**
+     * Get current mute status.
+     *
+     * \return the mute status (boolean) if defined, -1 if undefined/unapplicable
+     */
+    bool getMute();
+
 public slots:
     /*! \brief Set the media position.
 
