@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "albumdelegate.h"
 #include "albumlistview.h"
@@ -59,20 +43,19 @@ void AlbumDataDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
 //        return;
 //    }
 
-#ifdef TABLET_PC
-    if (listview->viewMode() == QListView::IconMode) {
-        drawTabletIconMode(*painter, option, index);
+    if (CommonService::getInstance()->isTabletEnvironment()) {
+        if (listview->viewMode() == QListView::IconMode) {
+            drawTabletIconMode(*painter, option, index);
+        } else {
+            this->drawListMode(*painter, option, index);
+        }
     } else {
-        this->drawListMode(*painter, option, index);
+        if (listview->viewMode() == QListView::IconMode) {
+            this->drawIconMode(*painter, option, index);
+        } else {
+            this->drawListMode(*painter, option, index);
+        }
     }
-#else
-    if (listview->viewMode() == QListView::IconMode) {
-        this->drawIconMode(*painter, option, index);
-    } else {
-        this->drawListMode(*painter, option, index);
-    }
-#endif
-
 }
 
 QSize AlbumDataDelegate::sizeHint(const QStyleOptionViewItem &option,
@@ -80,11 +63,11 @@ QSize AlbumDataDelegate::sizeHint(const QStyleOptionViewItem &option,
 {
     auto *listview = qobject_cast<const AlbumListView *>(option.widget);
     if (listview && listview->viewMode() == QListView::IconMode) {
-#ifdef TABLET_PC
-        return QSize(200, 200);
-#else
-        return QSize(150, 150);
-#endif
+        if (CommonService::getInstance()->isTabletEnvironment()) {
+            return QSize(200, 200);
+        } else {
+            return QSize(150, 150);
+        }
     } else {
         auto baseSize = QStyledItemDelegate::sizeHint(option, index);
         return QSize(baseSize.width(), 38);
@@ -93,64 +76,62 @@ QSize AlbumDataDelegate::sizeHint(const QStyleOptionViewItem &option,
 
 bool AlbumDataDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option, const QModelIndex &index)
 {
-#ifdef TABLET_PC
-    const AlbumListView *albumlistView = qobject_cast<const AlbumListView *>(option.widget);
-    const QMouseEvent *pressEvent = static_cast<QMouseEvent *>(event);
-    const QPointF pressPos = pressEvent->pos();
+    if (CommonService::getInstance()->isTabletEnvironment()) {
+        const AlbumListView *albumlistView = qobject_cast<const AlbumListView *>(option.widget);
+        const QMouseEvent *pressEvent = static_cast<QMouseEvent *>(event);
+        const QPointF pressPos = pressEvent->pos();
 
-    if (index.isValid() && (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonDblClick)) {
-        // 用于判断触屏点击状态
-        static int clickedCount = 0;
-        // 触屏点击次数
-        clickedCount++;
+        if (index.isValid() && (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonDblClick)) {
+            // 用于判断触屏点击状态
+            static int clickedCount = 0;
+            // 触屏点击次数
+            clickedCount++;
 
-        QTimer::singleShot(200, [ = ]() {
-            if (clickedCount == 1) {
-                if (albumlistView->viewMode() == QListView::IconMode) {
-                    // IconMode触屏单击
-                    touchClicked(option, index, pressPos);
-                } else if (albumlistView->viewMode() == QListView::ListMode) {
-                    // 同鼠标双击，进入二级菜单
+            QTimer::singleShot(200, [ = ]() {
+                if (clickedCount == 1) {
+                    if (albumlistView->viewMode() == QListView::IconMode) {
+                        // IconMode触屏单击
+                        touchClicked(option, index, pressPos);
+                    } else if (albumlistView->viewMode() == QListView::ListMode) {
+                        // 同鼠标双击，进入二级菜单
+                        mouseDoubleClicked(option, index);
+                    }
+                } else if (clickedCount > 1) {
+                    // 触屏双击
+                    touchDoubleClicked(option, index);
+                }
+                // 点击次数归零
+                clickedCount = 0;
+            });
+        }
+    } else {
+        const AlbumListView *albumlistView = qobject_cast<const AlbumListView *>(option.widget);
+        const QMouseEvent *pressEvent = static_cast<QMouseEvent *>(event);
+        const QPointF pressPos = pressEvent->pos();
+
+        if (index.isValid() && albumlistView->viewMode() == QListView::IconMode &&
+                (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonDblClick)) {
+            // 用于判断鼠标点击状态
+            static int clickedCount = 0;
+            // 鼠标点击次数
+            clickedCount++;
+
+            QTimer::singleShot(200, [ = ]() {
+                if (clickedCount == 1) {
+                    // 鼠标单击
+                    mouseClicked(option, index, pressPos);
+                } else if (clickedCount > 1) {
+                    // 鼠标双击
                     mouseDoubleClicked(option, index);
                 }
-            } else if (clickedCount > 1) {
-                // 触屏双击
-                touchDoubleClicked(option, index);
-            }
-            // 点击次数归零
-            clickedCount = 0;
-        });
+                // 点击次数归零
+                clickedCount = 0;
+            });
+        } else if (index.isValid() && albumlistView->viewMode() == QListView::ListMode && event->type() == QEvent::MouseButtonDblClick) {
+            // 鼠标双击
+            mouseDoubleClicked(option, index);
+        }
     }
-#else
-    const AlbumListView *albumlistView = qobject_cast<const AlbumListView *>(option.widget);
-    const QMouseEvent *pressEvent = static_cast<QMouseEvent *>(event);
-    const QPointF pressPos = pressEvent->pos();
-
-    if (index.isValid() && albumlistView->viewMode() == QListView::IconMode &&
-            (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonDblClick)) {
-        // 用于判断鼠标点击状态
-        static int clickedCount = 0;
-        // 鼠标点击次数
-        clickedCount++;
-
-        QTimer::singleShot(200, [ = ]() {
-            if (clickedCount == 1) {
-                // 鼠标单击
-                mouseClicked(option, index, pressPos);
-            } else if (clickedCount > 1) {
-                // 鼠标双击
-                mouseDoubleClicked(option, index);
-            }
-            // 点击次数归零
-            clickedCount = 0;
-        });
-    } else if (index.isValid() && albumlistView->viewMode() == QListView::ListMode && event->type() == QEvent::MouseButtonDblClick) {
-        // 鼠标双击
-        mouseDoubleClicked(option, index);
-    }
-#endif
-
-
     return QStyledItemDelegate::editorEvent(event, model, option, index);
 }
 
@@ -303,7 +284,6 @@ void AlbumDataDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewIt
     painter.fillRect(option.rect, fillBrush);
 }
 
-#ifdef TABLET_PC
 QPixmap blurPixmap(const QPixmap &pix, int radius, int tp, const QRect &clipRect)
 {
     QPixmap tmpPixmap = pix;
@@ -481,7 +461,6 @@ void AlbumDataDelegate::drawTabletIconMode(QPainter &painter, const QStyleOption
     painter.restore();
     painter.fillRect(option.rect, fillBrush);
 }
-#endif
 
 void AlbumDataDelegate::drawListMode(QPainter &painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
@@ -703,7 +682,7 @@ void AlbumDataDelegate::mouseDoubleClicked(const QStyleOptionViewItem &option, c
         emit CommonService::getInstance()->signalSwitchToView(SearchAlbumSubSongListType, "", albumTmp.musicinfos);
     }
 }
-#ifdef TABLET_PC
+
 void AlbumDataDelegate::touchClicked(const QStyleOptionViewItem &option, const QModelIndex &index, const QPointF pressPos)
 {
     const AlbumListView *albumlistView = qobject_cast<const AlbumListView *>(option.widget);
@@ -763,7 +742,7 @@ void AlbumDataDelegate::touchDoubleClicked(const QStyleOptionViewItem &option, c
         }
     }
 }
-#endif
+
 AlbumDataDelegate::AlbumDataDelegate(QWidget *parent): QStyledItemDelegate(parent)
     , hoverPlayImg(DHiDPIHelper::loadNxPixmap(":/icons/deepin/builtin/actions/play_hover_36px.svg"))
     , hoverSuspendImg(DHiDPIHelper::loadNxPixmap(":/icons/deepin/builtin/actions/suspend_hover_36px.svg"))
