@@ -1,23 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "musicbaselistview.h"
 
 #include <QDebug>
@@ -150,6 +135,8 @@ void MusicBaseListView::init()
     model->appendRow(item);
 
     setMinimumHeight(model->rowCount() * 40);
+
+    setThemeType(DGuiApplicationHelper::instance()->themeType());
 }
 
 void MusicBaseListView::showContextMenu(const QPoint &pos)
@@ -189,6 +176,14 @@ void MusicBaseListView::showContextMenu(const QPoint &pos)
     menu.exec(globalPos);
 }
 
+void MusicBaseListView::setThemeType(int type)
+{
+    for (int i = 0; i < model->rowCount(); i++) {
+        auto curStandardItem = dynamic_cast<DStandardItem *>(model->itemFromIndex(model->index(i, 0)));
+        curStandardItem->setForeground(type == 1 ? QColor("#414D68") : QColor("#C0C6D4"));
+    }
+}
+
 //void MusicBaseListView::mousePressEvent(QMouseEvent *event)
 //{
 //    DListView::mousePressEvent(event);
@@ -201,7 +196,7 @@ void MusicBaseListView::dragEnterEvent(QDragEnterEvent *event)
     if (event->mimeData()->hasFormat("text/uri-list") || event->mimeData()->hasFormat("playlistview/x-datalist")) {
         qDebug() << "acceptProposedAction" << event;
         event->setDropAction(Qt::CopyAction);
-        event->acceptProposedAction();
+        event->accept();
     }
 }
 
@@ -210,8 +205,9 @@ void MusicBaseListView::dragMoveEvent(QDragMoveEvent *event)
     auto index = indexAt(event->pos());
     if (index.isValid() && (event->mimeData()->hasFormat("text/uri-list")  || event->mimeData()->hasFormat("playlistview/x-datalist"))) {
         event->setDropAction(Qt::CopyAction);
-        event->acceptProposedAction();
+        event->accept();
     } else {
+        event->acceptProposedAction();
         DListView::dragMoveEvent(event);
     }
 }
