@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "musicsonglistview.h"
 
@@ -55,8 +39,8 @@
 
 #define CDA_USER_ROLE "CdaRole"
 #define CDA_USER_ROLE_OFFSET 12  //userrole+12 防止和其他歌单role重叠
-#define DRAGICON_LEFTBORDER 16
-#define DRAGICON_TOPBORDER 6
+#define DRAGICON_LEFTBORDER 0
+#define DRAGICON_TOPBORDER 0
 #define DRAGICON_ROUNDRADIUS 10
 
 DGUI_USE_NAMESPACE
@@ -647,7 +631,8 @@ void MusicSongListView::resizeEvent(QResizeEvent *event)
 
 void MusicSongListView::keyReleaseEvent(QKeyEvent *event)
 {
-    if (event->key() == Qt::Key_Delete) {
+    // 重命名时不删除操作
+    if (event->key() == Qt::Key_Delete && (m_renameLineEdit == nullptr || !m_renameLineEdit->isVisible())) {
         rmvSongList();
     }
     DListView::keyReleaseEvent(event);
@@ -731,10 +716,10 @@ void MusicSongListView::dragEnterEvent(QDragEnterEvent *event)
 {
     if (event->source() != this && (event->mimeData()->hasFormat("text/uri-list") || event->mimeData()->hasFormat("playlistview/x-datalist"))) {
         event->setDropAction(Qt::CopyAction);
-        event->acceptProposedAction();
+        event->accept();
     } else if (event->source() == this) {
         event->setDropAction(Qt::MoveAction);
-        event->acceptProposedAction();
+        event->accept();
 
         m_dragScrollTimer.start(200);
         m_isDraging = true;
@@ -759,11 +744,13 @@ void MusicSongListView::dragMoveEvent(QDragMoveEvent *event)
         auto index = indexAt(event->pos());
         if (index.isValid()) {
             event->setDropAction(Qt::CopyAction);
-            event->acceptProposedAction();
+            event->accept();
+        } else {
+            event->ignore();
         }
     } else if (event->source() == this) {
         event->setDropAction(Qt::MoveAction);
-        event->acceptProposedAction();
+        event->accept();
 
         int curRow = highlightedRow();
         if (curRow == -1) curRow = m_model->rowCount() - 1;
@@ -982,5 +969,6 @@ void MusicSongListView::setThemeType(int type)
         auto curStandardItem = dynamic_cast<DStandardItem *>(m_model->itemFromIndex(m_model->index(i, 0)));
         curStandardItem->setForeground(type == 1 ? QColor("#414D68") : QColor("#C0C6D4"));
     }
+    emit sigThemeTypeChanged(type);
 }
 
