@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "playitemdelegate.h"
 
@@ -425,7 +409,7 @@ void PlayItemDelegate::drawTabletListMode(QPainter &painter, const QStyleOptionV
             }
             // Fixme:
             QFileInfo info(itemMeta.localPath);
-            if (!info.exists() && itemMeta.mmType != MIMETYPE_CDA) {
+            if ((!info.exists() || !Player::getInstance()->supportedSuffixStrList().contains(info.suffix().toLower())) && itemMeta.mmType != MIMETYPE_CDA) {
                 auto sz = QSizeF(20, 20);
                 auto icon = QIcon::fromTheme("icon_warning").pixmap(sz.toSize());
                 auto centerF = QRectF(rect).center();
@@ -580,6 +564,20 @@ void PlayItemDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewIte
         icon = qvariant_cast<QIcon>(value);
     }
     QRect pixmapRect(option.rect.x() + xoffset, option.rect.y() + yoffset, ImgWidthAndHeight, ImgWidthAndHeight);
+
+    // 绘制选中时的阴影
+    QBrush fillBrush(QColor(128, 128, 128, 0));
+    if (option.state & QStyle::State_Selected) {
+        fillBrush = QBrush(option.palette.highlight().color());
+    }
+    int borderWidth = 4;
+    painter.save();
+    QPainterPath borderPixmapRectPath;
+    borderPixmapRectPath.addRoundRect(pixmapRect.adjusted(-borderWidth, -borderWidth, borderWidth, borderWidth), roundRadius, roundRadius);
+    painter.setClipPath(borderPixmapRectPath);
+    painter.fillRect(pixmapRect.adjusted(-borderWidth, -borderWidth, borderWidth, borderWidth), fillBrush);
+    painter.restore();
+
     QPainterPath roundPixmapRectPath;
     roundPixmapRectPath.addRoundRect(pixmapRect, roundRadius, roundRadius);
     painter.setClipPath(roundPixmapRectPath);
@@ -663,18 +661,8 @@ void PlayItemDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewIte
     }
     painter.setPen(timedColor);
     painter.drawText(timeFillRect, Qt::AlignCenter, timeText);
-
-    // 绘制选中时的阴影
-    QBrush fillBrush(QColor(128, 128, 128, 0));
-    if (option.state & QStyle::State_Selected) {
-        fillBrush = QBrush(QColor(128, 128, 128, 90));
-    }
     painter.restore();
 
-    painter.save();
-    painter.setClipPath(roundPixmapRectPath);
-    painter.fillRect(pixmapRect, fillBrush);
-    painter.restore();
     // 绘制选中时右上角的选中图标
 //    if (option.state & QStyle::State_Selected) {
 //        QRect selectionRect(option.rect.x() +  option.rect.width() - 20, option.rect.y() + 2, 14, 14);
@@ -783,7 +771,7 @@ void PlayItemDelegate::drawListMode(QPainter &painter, const QStyleOptionViewIte
             PlayListView *playListView = qobject_cast<PlayListView *>(const_cast<QWidget *>(option.widget));
             // Fixme:
             QFileInfo info(itemMeta.localPath);
-            if (!info.exists() && itemMeta.mmType != MIMETYPE_CDA) {
+            if ((!info.exists() || !Player::getInstance()->supportedSuffixStrList().contains(info.suffix().toLower())) && itemMeta.mmType != MIMETYPE_CDA) {
                 auto sz = QSizeF(20, 20);
                 auto icon = QIcon::fromTheme("icon_warning").pixmap(sz.toSize());
                 auto centerF = QRectF(rect).center();
