@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "playlistview.h"
 
@@ -58,6 +42,8 @@
 #include "commonservice.h"
 #include "songlistview.h"
 #include "songlistviewdialog.h"
+#include "../util/eventlogutils.h"
+#include "config.h"
 
 DWIDGET_USE_NAMESPACE
 
@@ -668,6 +654,15 @@ void PlayListView::slotOnClicked(const QModelIndex &index)
         if (!QFileInfo(itemMeta.localPath).exists() && itemMeta.mmType != MIMETYPE_CDA) {
             //停止当前的歌曲
             Player::getInstance()->stop();
+
+            QJsonObject obj{
+                {"tid", EventLogUtils::StartPlaying},
+                {"version", VERSION},
+                {"successful", false},
+                {"encapsulation_format", itemMeta.filetype}//封装格式
+            };
+            EventLogUtils::get().writeLogs(obj);
+
             //弹出提示框
             showErrorDlg();
         } else {
@@ -686,6 +681,15 @@ void PlayListView::slotOnDoubleClicked(const QModelIndex &index)
     if (!fileInfo.exists() && itemMeta.mmType != MIMETYPE_CDA) {
         //停止当前的歌曲
         Player::getInstance()->stop();
+
+        QJsonObject obj{
+            {"tid", EventLogUtils::StartPlaying},
+            {"version", VERSION},
+            {"successful", false},
+            {"encapsulation_format", itemMeta.filetype}//封装格式
+        };
+        EventLogUtils::get().writeLogs(obj);
+
         //弹出提示框
         showErrorDlg();
     } else {
@@ -702,6 +706,11 @@ void PlayListView::slotLoadData()
     // 排序
     sortList(mediaMetas, sortType);
 
+    // 直接打开重复添加歌曲
+    for (int i = FirstLoadCount; i < m_model->rowCount(); ++i) {
+        m_model->removeRow(i);
+    }
+
     QList<MediaMeta> preMediaMetas = DataBaseService::getInstance()->getMusicInfosBySortAndCount(FirstLoadCount);
     for (int i = 0; i < mediaMetas.size(); i++) {
         //防止重复添加
@@ -1422,13 +1431,15 @@ QPixmap PlayListView::dragItemsPixmap()
     qreal scale = devicePixelRatio();
     QModelIndexList modelIndexList = allSelectedIndexes();
 
+    int leftBorder = m_dragFlag ? 0 : DRAGICON_LEFTBORDER;
+    int topBorder = m_dragFlag ? 0 : DRAGICON_TOPBORDER;
     QFont font;
     font.setPixelSize(10);
     QFontMetrics fontMetrics(font);
     int textSize = fontMetrics.width(QString("%1").arg(modelIndexList.size()));
     if (textSize < fontMetrics.height()) textSize = fontMetrics.height();
     int testRadius = textSize / 2 + DRAGICON_TEXTBORDERSIZE;
-    QRect pixRect(0, 0, DRAGICON_SIZE + DRAGICON_LEFTBORDER + testRadius, DRAGICON_SIZE + testRadius + DRAGICON_TOPBORDER + 10);
+    QRect pixRect(0, 0, DRAGICON_SIZE + leftBorder + testRadius, DRAGICON_SIZE + testRadius + topBorder + 10);
     QPixmap pixmap(pixRect.size() * scale);
     pixmap.setDevicePixelRatio(scale);
     pixmap.fill(Qt::transparent);
@@ -1439,7 +1450,7 @@ QPixmap PlayListView::dragItemsPixmap()
     QMatrix matrix;
     matrix.rotate(180.0);
     painter.save();
-    painter.translate(DRAGICON_LEFTBORDER + DRAGICON_SIZE, DRAGICON_TOPBORDER + DRAGICON_SIZE);
+    painter.translate(leftBorder + DRAGICON_SIZE, topBorder + DRAGICON_SIZE);
     // 绘制图片
     for (int i = qMin(modelIndexList.size() - 1, 2); i >= 0; --i) {
         QStandardItem *newItem = m_model->itemFromIndex(modelIndexList.at(i));
@@ -1472,11 +1483,11 @@ QPixmap PlayListView::dragItemsPixmap()
     painter.save();
     painter.setPen(Qt::NoPen);
     painter.setBrush(Qt::red);
-    painter.drawEllipse(QRect(DRAGICON_LEFTBORDER + DRAGICON_SIZE - testRadius, DRAGICON_TOPBORDER + DRAGICON_SIZE - testRadius, testRadius * 2, testRadius * 2));
+    painter.drawEllipse(QRect(leftBorder + DRAGICON_SIZE - testRadius, topBorder + DRAGICON_SIZE - testRadius, testRadius * 2, testRadius * 2));
     painter.setPen(Qt::white);
     painter.setFont(font);
     painter.setBrush(Qt::black);
-    painter.drawText(QRect(DRAGICON_LEFTBORDER + DRAGICON_SIZE - textSize / 2, DRAGICON_TOPBORDER + DRAGICON_SIZE - textSize / 2, textSize, textSize), QString("%1").arg(modelIndexList.size()), QTextOption(Qt::AlignCenter));
+    painter.drawText(QRect(leftBorder + DRAGICON_SIZE - textSize / 2, topBorder + DRAGICON_SIZE - textSize / 2, textSize, textSize), QString("%1").arg(modelIndexList.size()), QTextOption(Qt::AlignCenter));
     painter.restore();
 
     return pixmap;
@@ -1573,10 +1584,10 @@ void PlayListView::dragEnterEvent(QDragEnterEvent *event)
 {
     if (event->mimeData()->hasFormat("text/uri-list")) {
         event->setDropAction(Qt::CopyAction);
-        event->acceptProposedAction();
+        event->accept();
     } else if (event->source() == this && m_dragFlag) {
         event->setDropAction(Qt::MoveAction);
-        event->acceptProposedAction();
+        event->accept();
 
         m_dragScrollTimer.start(200);
         m_isDraging = true;
@@ -1605,10 +1616,10 @@ void PlayListView::dragMoveEvent(QDragMoveEvent *event)
 {
     if (event->mimeData()->hasFormat("text/uri-list")) {
         event->setDropAction(Qt::CopyAction);
-        event->acceptProposedAction();
+        event->accept();
     } else if (event->source() == this && m_dragFlag) {
         event->setDropAction(Qt::MoveAction);
-        event->acceptProposedAction();
+        event->accept();
 
         updateDropIndicator();
     }
