@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "singerdelegate.h"
 #include "singerlistview.h"
@@ -657,7 +641,7 @@ void SingerDataDelegate::mouseClicked(const QStyleOptionViewItem &option, const
         if (fillPolygon.containsPoint(pressPos, Qt::OddEvenFill)) {
             if (singertmp.musicinfos.values().size() > 0) {
                 emit CommonService::getInstance()->signalSetPlayModel(Player::RepeatAll);
-                Player::getInstance()->setCurrentPlayListHash("album", false);
+                Player::getInstance()->setCurrentPlayListHash("artist", false);
                 Player::getInstance()->setPlayList(singertmp.musicinfos.values());
                 Player::getInstance()->playMeta(singertmp.musicinfos.values().first());
                 emit Player::getInstance()->signalPlayListChanged();
