@@ -1,23 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "singerlistview.h"
 
 #include <QDebug>
@@ -134,7 +119,7 @@ SingerListView::SingerListView(const QString &hash, QWidget *parent)
 // 双击逻辑位置移动
 //    connect(this, &SingerListView::doubleClicked, this, &SingerListView::onDoubleClicked);
 
-    setSelectionMode(QListView::ExtendedSelection);
+    setSelectionMode(QListView::SingleSelection);
     setSelectionBehavior(QAbstractItemView::SelectRows);
 
     connect(DataBaseService::getInstance(), &DataBaseService::signalCoverUpdate,
@@ -674,7 +659,7 @@ void SingerListView::slotRemoveSelectedSongs(const QString &deleteHash, const QS
 {
     Q_UNUSED(removeFromLocal)
     QString curDeleteHash = deleteHash;
-    if (curDeleteHash != "artist" || Player::getInstance()->getCurrentPlayListHash() != "artist") {
+    if (curDeleteHash != m_hash || Player::getInstance()->getCurrentPlayListHash() != m_hash) {
         return;
     }
     if (musicHashs.size() == 0 || Player::getInstance()->getPlayList()->isEmpty()) {
