@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "footerwidget.h"
 
@@ -91,7 +75,10 @@ FooterWidget::FooterWidget(QWidget *parent) :
 
 FooterWidget::~FooterWidget()
 {
-
+    // 取消
+    if (m_lastCookie > 0) {
+        screenStandby(false);
+    }
 }
 
 void FooterWidget::initUI(QWidget *parent)
@@ -122,7 +109,7 @@ void FooterWidget::initUI(QWidget *parent)
 //    layout->setContentsMargins(0, 0, 10, 0);
 //    mainVBoxlayout->addWidget(downWidget);
 
-    m_btPrev = new DButtonBoxButton(QIcon::fromTheme("music_last"), "", this);
+    m_btPrev = new DButtonBoxButton(QIcon(":/icons/deepin/builtin/texts/music_last_36px.svg"), "", this);
     m_btPrev->setIconSize(QSize(36, 36));
     m_btPrev->setObjectName("FooterActionPrev");
     m_btPrev->setFixedSize(40, 50);
@@ -136,7 +123,7 @@ void FooterWidget::initUI(QWidget *parent)
     AC_SET_OBJECT_NAME(m_btPlay, AC_Play);
     AC_SET_ACCESSIBLE_NAME(m_btPlay, AC_Play);
 
-    m_btNext = new DButtonBoxButton(QIcon::fromTheme("music_next"), "", this);
+    m_btNext = new DButtonBoxButton(QIcon(":/icons/deepin/builtin/texts/music_next_36px.svg"), "", this);
     m_btNext->setIconSize(QSize(36, 36));
     m_btNext->setObjectName("FooterActionNext");
     m_btNext->setFixedSize(40, 50);
@@ -441,8 +428,10 @@ void FooterWidget::setPlayProperty(Player::PlaybackStatus status)
 {
     if (status != Player::PlaybackStatus::Playing) {
         m_btPlay->setIcon(QIcon::fromTheme("music_play"));
+        screenStandby(false);
     } else {
         m_btPlay->setIcon(QIcon::fromTheme("suspend"));
+        screenStandby(true);
     }
 }
 
@@ -800,6 +789,37 @@ void FooterWidget::slotSetWaveValue(int step, long duration)
     m_waveform->onProgressChanged(step, duration, 1); //1:偏移率
 }
 
+void FooterWidget::screenStandby(bool isStandby)
+{
+    if (!Global::boardVendorType())
+        return;
+    if (isStandby) {
+        if (m_lastCookie > 0) {
+            QDBusInterface iface("org.freedesktop.ScreenSaver",
+                                 "/org/freedesktop/ScreenSaver",
+                                 "org.freedesktop.ScreenSaver");
+            iface.call("UnInhibit", m_lastCookie);
+            m_lastCookie = 0;
+        }
+        QDBusInterface iface("org.freedesktop.ScreenSaver",
+                             "/org/freedesktop/ScreenSaver",
+                             "org.freedesktop.ScreenSaver");
+        QDBusReply<uint32_t> reply = iface.call("Inhibit", "deepin-music", "playing in fullscreen");
+
+        if (reply.isValid()) {
+            m_lastCookie = reply.value();
+        }
+    } else {
+        if (m_lastCookie > 0) {
+            QDBusInterface iface("org.freedesktop.ScreenSaver",
+                                 "/org/freedesktop/ScreenSaver",
+                                 "org.freedesktop.ScreenSaver");
+            iface.call("UnInhibit", m_lastCookie);
+            m_lastCookie = 0;
+        }
+    }
+}
+
 void FooterWidget::resizeEvent(QResizeEvent *event)
 {
     if (m_forwardWidget) {
@@ -883,6 +903,9 @@ void FooterWidget::slotTheme(int type)
         pl.setColor(DPalette::FrameBorder, framecolor);
         pl.setColor(DPalette::Shadow, framecolor);
         DApplicationHelper::instance()->setPalette(m_ctlWidget, pl);
+
+        m_btPrev->setIcon(QIcon(":/icons/deepin/builtin/texts/music_last_36px.svg"));
+        m_btNext->setIcon(QIcon(":/icons/deepin/builtin/texts/music_next_36px.svg"));
     } else {
         QColor maskColor(32, 32, 32);
         maskColor.setAlphaF(0.80);
@@ -919,6 +942,9 @@ void FooterWidget::slotTheme(int type)
         pl.setColor(DPalette::FrameBorder, framecolor);
         pl.setColor(DPalette::Shadow, framecolor);
         DApplicationHelper::instance()->setPalette(m_ctlWidget, pl);
+
+        m_btPrev->setIcon(QIcon(":/icons/deepin/builtin/texts/music_last_light_36px.svg"));
+        m_btNext->setIcon(QIcon(":/icons/deepin/builtin/texts/music_next_light_36px.svg"));
     }
 
     m_waveform->setThemeType(type);
