@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
@@ -68,6 +52,8 @@ public:
      * @param duration 整体时长ms
      */
     void slotSetWaveValue(int step, long duration);
+    // 阻止休眠
+    void screenStandby(bool isStandby);
 private:
     void initUI(QWidget *parent = nullptr);
     void installTipHint(QWidget *widget, const QString &hintstr);
@@ -156,6 +142,7 @@ private:
     SoundVolume        *m_volSlider  = nullptr;
     MetaBufferDetector  m_metaBufferDetector;
     HintFilter          *m_hintFilter = nullptr;
+    quint32             m_lastCookie = 0;
 
     QTimer             *m_limitRepeatClick = nullptr;
 };
