@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "mainframe.h"
 
@@ -56,6 +40,7 @@
 #include <unistd.h>
 #include "./core/musicsettings.h"
 #include "./core/util/global.h"
+#include "../core/util/eventlogutils.h"
 
 #include "../widget/titlebarwidget.h"
 #include "musicstackedwidget.h"
@@ -75,6 +60,7 @@
 #include "tabletlabel.h"
 #include "comdeepiniminterface.h"
 #include "dbusutils.h"
+#include "config.h"
 DWIDGET_USE_NAMESPACE
 
 const QString s_PropertyViewname = "viewname";
@@ -1003,6 +989,14 @@ void MainFrame::showEvent(QShowEvent *event)
         this->setMinimumSize(QSize(1070, 680));
         this->resize(QSize(1070, 680));
         Dtk::Widget::moveToCenter(this);
+
+        QJsonObject obj{
+            {"tid", EventLogUtils::Start},
+            {"version", VERSION},
+            {"mode", 1} //冷启动
+        };
+        EventLogUtils::get().writeLogs(obj);
+
     } else {
         QDataStream stream(m_geometryBa); //仅在程序运行期间生效
         stream.setVersion(QDataStream::Qt_4_0);
@@ -1041,7 +1035,13 @@ void MainFrame::showEvent(QShowEvent *event)
             qint32 restoredScreenWidth = 0;
             stream >> restoredScreenWidth;
         }
-//        restoreGeometry(m_geometryBa);
+
+        QJsonObject obj{
+            {"tid", EventLogUtils::Start},
+            {"version", VERSION},
+            {"mode", 2} //热启动
+        };
+        EventLogUtils::get().writeLogs(obj);
     }
     this->setFocus();
 
