@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
@@ -64,9 +48,13 @@ public:
     void initTabletSelectBtn();
     // 初始化平板菜单
     void initPadMenu();
+    // 检查窗口状态
+    bool checkWindowVisible(bool waylandMode);
 public slots:
     // 显示弹窗消息
     void showPopupMessage(const QString &songListName, int selectCount, int insertCount);
+    // 显示解码失败消息
+    void decodingErrorMessage();
     // 左上角返回按钮点击
     void slotLeftClicked();
     // 虚拟键盘
@@ -159,6 +147,7 @@ private:
     QString             m_selectAllStr;
     QString             m_doneStr;
     bool                m_contentUpByKeyBoard = false;
+    bool                m_preMaxFlag = false;
     ComDeepinImInterface *m_comDeepinImInterface = nullptr;
 };
 
