@@ -1,23 +1,6 @@
-﻿/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "musiclistdatawidget.h"
 
@@ -163,6 +146,9 @@ void MusicListDataWidget::slotViewChanged(ListPageSwitchType switchtype, const Q
             m_pStackedWidget->addWidget(m_albumListView);
             AC_SET_OBJECT_NAME(m_albumListView, AC_albumListView);
             AC_SET_ACCESSIBLE_NAME(m_albumListView, AC_albumListView);
+            connect(m_albumListView, &AlbumListView::rowCountChanged, this, [=](){
+                this->refreshInfoLabel("album");
+            });
         }
         //防止第一次无数据
         if (DataBaseService::getInstance()->allMusicInfos(false).isEmpty()) {
@@ -187,6 +173,9 @@ void MusicListDataWidget::slotViewChanged(ListPageSwitchType switchtype, const Q
             m_pStackedWidget->addWidget(m_singerListView);
             AC_SET_OBJECT_NAME(m_singerListView, AC_singerListView);
             AC_SET_ACCESSIBLE_NAME(m_singerListView, AC_singerListView);
+            connect(m_singerListView, &SingerListView::rowCountChanged, this, [=](){
+                this->refreshInfoLabel("artist");
+            });
         }
         //防止第一次无数据
         if (DataBaseService::getInstance()->allMusicInfos(false).isEmpty()) {
