@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
@@ -67,16 +51,19 @@ public slots:
     void slotPlaylistNameUpdate(const QString &listHash);
 protected:
     bool eventFilter(QObject *o, QEvent *e) Q_DECL_OVERRIDE;
+
 protected:
     virtual void dragEnterEvent(QDragEnterEvent *event) Q_DECL_OVERRIDE;
     virtual void dropEvent(QDropEvent *event) Q_DECL_OVERRIDE;
     virtual void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
     virtual void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+
 private slots:
     // 播放所有歌曲
     void slotPlayAllClicked();
     // 歌曲列表数量变化
     void slotMusicRowCountChanged();
+
 private:
     void initUI();
     void initTitle(QHBoxLayout *layout);
@@ -92,6 +79,8 @@ private:
     void refreshModeBtn(DListView::ViewMode mode);
     // 刷新当前排序菜单
     void refreshSortAction(const QString &hash = "");
+    // 播放歌曲
+    void playMetas(QList<MediaMeta> &metas);
 private:
     DWidget             *m_contentWidget           = nullptr;
     QStackedWidget      *m_pStackedWidget          = nullptr;
@@ -121,6 +110,7 @@ private:
     QString             m_currentHash;
     ListPageSwitchType  m_preSwitchtype            = AllSongListType;
     QString             m_preHash                  = "all";//记录前一次显示，当清除搜索时回到上一页面
+    QString             m_countStr;
 };
 
 class ActionBar : public DWidget
