@@ -1,23 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "subsonglistwidget.h"
 
 #include <QDebug>
@@ -65,10 +50,10 @@ void SubSonglistWidget::initUI()
     titleLayout->setContentsMargins(28, 15, 0, 20);
 
     m_titleLabel = new DLabel(this);
-    m_titleLabel->setForegroundRole(DPalette::BrightText);
+    m_titleLabel->setForegroundRole(DPalette::TextTitle);
     titleLayout->addWidget(m_titleLabel, 1);
     m_infoLabel = new DLabel(this);
-    m_infoLabel->setForegroundRole(DPalette::BrightText);
+    m_infoLabel->setForegroundRole(DPalette::TextTitle);
     titleLayout->addWidget(m_infoLabel, 1);
     QHBoxLayout *btLayout = new QHBoxLayout(this);
     btLayout->setSpacing(5);
@@ -90,11 +75,10 @@ void SubSonglistWidget::initUI()
     // 按钮自适应字体大小
     int btnWidth = CommonService::getInstance()->isTabletEnvironment() ? 100 : 93;
     int btnHight = CommonService::getInstance()->isTabletEnvironment() ? 40 : 30;
-    m_btPlayAll->setFixedSize(QSize(btnWidth, btnHight));
+    m_btPlayAll->setMinimumSize(QSize(btnWidth, btnHight));
     // 字体宽度加图标大于93,重新设置按钮宽度
     QFontMetrics font(m_btPlayAll->font());
-    m_btPlayAll->setFixedWidth((font.width(m_btPlayAll->text()) + 18) >= btnWidth ? (font.width(m_btPlayAll->text()) + 38) : btnWidth);
-
+    m_btPlayAll->setMinimumWidth((font.width(m_btPlayAll->text()) + 18) >= btnWidth ? (font.width(m_btPlayAll->text()) + 38) : btnWidth);
     DFontSizeManager::instance()->bind(m_btPlayAll, DFontSizeManager::T6, QFont::Medium);
     btLayout->addWidget(m_btPlayAll);
 
@@ -110,10 +94,10 @@ void SubSonglistWidget::initUI()
     m_btRandomPlay->setFocusPolicy(Qt::NoFocus);
     m_btRandomPlay->setIconSize(QSize(18, 18));
     // 按钮自适应字体大小
-    m_btRandomPlay->setFixedSize(QSize(btnWidth, btnHight));
+    m_btRandomPlay->setMinimumSize(QSize(btnWidth, btnHight));
     // 字体宽度加图标大于93,重新设置按钮宽度
     QFontMetrics fontRandom(m_btRandomPlay->font());
-    m_btRandomPlay->setFixedWidth((fontRandom.width(m_btRandomPlay->text()) + 18) >= btnWidth ? (fontRandom.width(m_btRandomPlay->text()) + 38) : btnWidth);
+    m_btRandomPlay->setMinimumWidth((fontRandom.width(m_btRandomPlay->text()) + 18) >= btnWidth ? (fontRandom.width(m_btRandomPlay->text()) + 38) : btnWidth);
     DFontSizeManager::instance()->bind(m_btRandomPlay, DFontSizeManager::T6, QFont::Medium);
     btLayout->addWidget(m_btRandomPlay);
     btLayout->addStretch();
@@ -147,21 +131,7 @@ void SubSonglistWidget::resizeEvent(QResizeEvent *e)
     QString title = extraNameFm.elidedText(m_title, Qt::ElideRight, this->width() - 56);
     m_titleLabel->setText(title);
 
-    // 添加非空判断，减少警告日志输出与不必要的性能损耗
-    QImage img;
-    if (!m_img.isNull()) {
-        // 根据屏幕缩放比调整
-        img = m_img.scaled(static_cast<int>(static_cast<double>(this->width()) * qApp->devicePixelRatio()), 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation).toImage();
-    }
-    QPainter pai(&img);
-    pai.setRenderHints(QPainter::Antialiasing | QPainter::HighQualityAntialiasing | QPainter::SmoothPixmapTransform);
-    QColor fillColor("#FFFFFF");
-    fillColor.setAlphaF(0.6);
-    pai.setBrush(fillColor);
-    QRect rect = img.rect();
-    rect.adjust(-5, 0, 5, 0);
-    pai.drawRect(rect);
-    m_titleImage->setPixmap(QPixmap::fromImage(img));
+    setTitleImage(m_img);
 }
 
 SubSonglistWidget::SubSonglistWidget(const QString &hash, QWidget *parent)
@@ -188,13 +158,8 @@ void SubSonglistWidget::setThemeType(int type)
         palette.setColor(DPalette::Background, BackgroundColor);
         setPalette(palette);
 
-//        auto titleLabelPl = d->titleLabel->palette();
-//        titleLabelPl.setColor(DPalette::WindowText, Qt::black);
-//        d->titleLabel->setPalette(titleLabelPl);
-
-//        auto infoLabelPl = d->infoLabel->palette();
-//        infoLabelPl.setColor(DPalette::WindowText, Qt::black);
-//        d->infoLabel->setPalette(infoLabelPl);
+        m_titleLabel->setForegroundRole(DPalette::TextTitle);
+        m_infoLabel->setForegroundRole(DPalette::TextTitle);
 
         auto playAllPalette = m_btPlayAll->palette();
         playAllPalette.setColor(DPalette::ButtonText, Qt::white);
@@ -219,13 +184,8 @@ void SubSonglistWidget::setThemeType(int type)
         palette.setColor(DPalette::Background, BackgroundColor);
         setPalette(palette);
 
-//        auto titleLabelPl = d->titleLabel->palette();
-//        titleLabelPl.setColor(DPalette::WindowText, Qt::white);
-//        d->titleLabel->setPalette(titleLabelPl);
-
-//        auto infoLabelPl = d->infoLabel->palette();
-//        infoLabelPl.setColor(DPalette::WindowText, Qt::white);
-//        d->infoLabel->setPalette(infoLabelPl);
+        m_titleLabel->setForegroundRole(DPalette::HighlightedText);
+        m_infoLabel->setForegroundRole(DPalette::HighlightedText);
 
         auto playAllPalette = m_btPlayAll->palette();
         playAllPalette.setColor(DPalette::ButtonText, "#FFFFFF");
@@ -248,6 +208,7 @@ void SubSonglistWidget::setThemeType(int type)
     m_btPlayAll->setIcon(QIcon::fromTheme("play_all"));
     m_btRandomPlay->setIcon(QIcon::fromTheme("random_play"));
 //    infoDialog->setThemeType(type);
+    setTitleImage(m_img);
 }
 
 void SubSonglistWidget::flushDialog(QMap<QString, MediaMeta> musicinfos, ListPageSwitchType listPageType)
@@ -297,7 +258,6 @@ void SubSonglistWidget::flushDialog(QMap<QString, MediaMeta> musicinfos, ListPag
         DFontSizeManager::instance()->bind(m_titleLabel, DFontSizeManager::T3, QFont::DemiBold);
         m_infoLabel->setFont(infoFont);
         DFontSizeManager::instance()->bind(m_infoLabel, DFontSizeManager::T5, QFont::Normal);
-        m_titleLabel->setForegroundRole(DPalette::TextTitle);
 
         // 设置titleImage
         QPixmap img;
@@ -305,7 +265,7 @@ void SubSonglistWidget::flushDialog(QMap<QString, MediaMeta> musicinfos, ListPag
             QString imagesDirPath = Global::cacheDir() + "/images/" + meta.hash + ".jpg";
             // 查找可用图片
             if (QFileInfo(imagesDirPath).exists()) {
-                img = MetaDetector::getCoverDataPixmap(meta);
+                img = MetaDetector::getCoverDataPixmap(meta, Global::playbackEngineType());
                 break;
             }
         }
@@ -329,6 +289,8 @@ void SubSonglistWidget::slotPlayAllClicked()
 {
     QList<MediaMeta> musicList = m_musicListInfoView->getMusicListData();
     if (musicList.size() > 0) {
+        // 清空播放队列
+        Player::getInstance()->clearPlayList();
         Player::getInstance()->setCurrentPlayListHash(m_hash, false);
         Player::getInstance()->setPlayList(musicList);
         Player::getInstance()->playMeta(musicList.first());
@@ -353,22 +315,24 @@ void SubSonglistWidget::setTitleImage(QPixmap &img)
 {
     m_img = img;
 
+    QPixmap curImg;
     // 添加非空判断，减少警告日志输出与不必要的性能损耗
     if (!img.isNull()) {
-        img = img.scaled(static_cast<int>(static_cast<double>(this->width()) * qApp->devicePixelRatio()), 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
+        curImg = img.scaled(static_cast<int>(static_cast<double>(this->width()) * qApp->devicePixelRatio()), 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
     }
 
-    QPainter pai(&img);
+    QPainter pai(&curImg);
     pai.setRenderHints(QPainter::Antialiasing | QPainter::HighQualityAntialiasing | QPainter::SmoothPixmapTransform);
 
     QColor fillColor("#FFFFFF");
+    if (DGuiApplicationHelper::instance()->themeType() != 1)
+        fillColor = QColor(Qt::black);
     fillColor.setAlphaF(0.6);
     pai.setBrush(fillColor);
-    QRect rect = img.rect();
+    QRect rect = curImg.rect();
     rect.adjust(-5, 0, 5, 0);
     pai.drawRect(rect);
+    pai.end();
 
-    m_titleImage->setPixmap(img);
+    m_titleImage->setPixmap(curImg);
 }
-
-
