@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dboperate.h"
 #include <QDebug>
@@ -101,6 +85,7 @@ void DBOperate::slotImportMedias(const QString &importHash, QString playHash, co
     m_importFailCount = 0;
     // 包含导入成功和失败的
     double importedCount = 0;
+    qint64 preTime = QDateTime::currentDateTime().toMSecsSinceEpoch() * 1000;
     if (m_db.transaction()) {
         for (auto &filepath : urllist) {
             if (filepath.isEmpty()) {
@@ -127,6 +112,8 @@ void DBOperate::slotImportMedias(const QString &importHash, QString playHash, co
                     }
                     QString  strtp = it.next();
                     MediaMeta mediaMeta = m_mediaLibrary->creatMediaMeta(strtp);
+                    mediaMeta.timestamp = preTime >= mediaMeta.timestamp ? (preTime + 1) : mediaMeta.timestamp;
+                    preTime = mediaMeta.timestamp;
                     if (mediaMeta.length <= 0) {
                         m_importFailCount++;
                         importedCount++;
@@ -164,6 +151,8 @@ void DBOperate::slotImportMedias(const QString &importHash, QString playHash, co
                     continue;
                 }
                 MediaMeta mediaMeta = m_mediaLibrary->creatMediaMeta(strtp);
+                mediaMeta.timestamp = preTime >= mediaMeta.timestamp ? (preTime + 1) : mediaMeta.timestamp;
+                preTime = mediaMeta.timestamp;
                 if (mediaMeta.length <= 0) {
                     m_importFailCount++;
                 } else {
@@ -202,10 +191,11 @@ void DBOperate::slotCreatCoverImg(const QList<MediaMeta> &metas)
             m_needSleep = false;
         }
         //没有加载过的文件才去解析数据
-
         QFileInfo coverInfo(Global::cacheDir() + "/images/" + meta.hash + ".jpg");
         if (!coverInfo.exists()) {
-            meta.getCoverData(Global::cacheDir());
+            //taglib无法解析mp3格式之外的音频封面，所以需要在这里进行选择性过滤
+            if (Global::playbackEngineType() == 1 || QFileInfo(meta.localPath).suffix().contains("mp3", Qt::CaseInsensitive))
+                meta.getCoverData(Global::cacheDir(), Global::playbackEngineType());
         }
         emit sigCreatOneCoverImg(meta);
     }
