@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "lyriclabel.h"
 
@@ -50,13 +34,10 @@ LyricLabel::LyricLabel(bool touch, QWidget *parent)
     AC_SET_OBJECT_NAME(this, AC_lyricview);
     AC_SET_ACCESSIBLE_NAME(this, AC_lyricview);
 
-//    lyric = new MusicLyric();
-//    lyricFont = new QFont();
     lyricFont.setFamily("SourceHanSansSC");
     lyricFont.setWeight(QFont::Normal);
 
 // 解决字体不会根据系统字体大小改变问题
-//    lyricFont.setPixelSize(14);
     lyricNormal = QColor("#526A7F");
     lyricHighlight = QColor("#000000");
     connect(this, &LyricLabel::changeTo, this, &LyricLabel::changeToEvent);
@@ -68,23 +49,6 @@ LyricLabel::LyricLabel(bool touch, QWidget *parent)
             this, &LyricLabel::setThemeType);
 
     setThemeType(DGuiApplicationHelper::instance()->themeType());
-
-    /* MyMenu *menu = new MyMenu(this);
-     QAction *selectLyric = new QAction("关联本地歌词", menu);
-     QAction *fontSelect = new QAction("字体设置", menu);
-     connect(fontSelect, SIGNAL(triggered(bool)), this, SLOT(changeFont()));
-    // QAction *colorNormal = new QAction("普通颜色", menu);
-    QAction *colorNormal = new QAction("pp", menu);
-     connect(colorNormal, SIGNAL(triggered(bool)), this, SLOT(changeNormalColor()));
-     QAction *colorHighLight = new QAction("高亮颜色", menu);
-     connect(colorHighLight, SIGNAL(triggered(bool)), this, SLOT(changeHightLightColor()));
-     menu->addAction(selectLyric);
-     menu->addSeparator();
-     menu->addAction(fontSelect);
-     menu->addAction(colorNormal);
-     menu->addAction(colorHighLight);
-     connect(this, SIGNAL(rightClicked()), menu, SLOT(menuVisiable()));*/
-    //setMinimumWidth(600);
 }
 
 void LyricLabel::getFromFile(QString dir)
@@ -96,20 +60,17 @@ void LyricLabel::getFromFile(QString dir)
 void LyricLabel::paintItem(QPainter *painter, int index, const QRect &rect)
 {
     if (index == this->m_currentItem) {
-        painter->setPen(lyricHighlight);
+//        painter->setPen(lyricHighlight);
         QFont font(lyricFont);
         //绑定获取系统字体大小
         font.setPixelSize(DFontSizeManager::instance()->fontPixelSize(DFontSizeManager::T6));
         painter->setFont(font);
         QPoint leftpos = rect.bottomLeft();
-        leftpos.setY(static_cast<int>(leftpos.y() + rect.height() / 2.0 + 5));
         QPoint rightpos = rect.bottomRight();
         rightpos.setY(leftpos.y());
         rightpos.setX(rightpos.x() - 3);
-        leftpos.setY(leftpos.y() - 3);
-        rightpos.setY(rightpos.y() - 3);
-        //leftpos.setY(leftpos.y() - rect.height() / 2);
-        //rightpos.setY(rightpos.y() - rect.height() / 2);
+        leftpos.setY(leftpos.y() - rect.height() / 2);
+        rightpos.setY(rightpos.y() - rect.height() / 2);
         painter->save();
         QPointF triangle1[3] = {QPointF(leftpos.x(), leftpos.y() * 1.0 + 4.5), QPointF(leftpos.x(), leftpos.y() * 1.0 - 4.5), QPointF(leftpos.x() + 9, leftpos.y())}; //1
         QPointF triangle2[3] = {QPointF(rightpos.x(), rightpos.y() * 1.0 + 4.5), QPointF(rightpos.x(), rightpos.y() * 1.0 - 4.5), QPointF(rightpos.x() - 9, rightpos.y())}; //1
@@ -129,15 +90,16 @@ void LyricLabel::paintItem(QPainter *painter, int index, const QRect &rect)
 
         painter->drawLine(leftpos.x() + 23, leftpos.y(), rightpos.x() - 23, rightpos.y());
         painter->restore();
-    } else {
-        QPen pen = painter->pen();
-        QColor color = pen.color();
-        color.setRed(lyricNormal.red());
-        color.setGreen(lyricNormal.green());
-        color.setBlue(lyricNormal.blue());
-        painter->setPen(color);
-        painter->setFont(lyricFont);
     }
+
+    QPen pen = painter->pen();
+    QColor color = pen.color();
+    color.setRed(lyricNormal.red());
+    color.setGreen(lyricNormal.green());
+    color.setBlue(lyricNormal.blue());
+    painter->setPen(index == this->m_currentItem ? lyricHighlight : color);
+    painter->setFont(lyricFont);
+
     QFontMetrics fm(lyricFont);
     QString lricstr = lyric.getLineAt(index);
     QPoint tleftpos = rect.topLeft();
@@ -180,7 +142,7 @@ void LyricLabel::postionChanged(qint64 pos)
 {
     if (this->isScrolled) return;
     pos = pos + 500; //歌词滚动需要500ms
-    int index = lyric.getIndex(pos) - 1;
+    int index = lyric.getIndex(pos);
     if (index != m_currentItem)
         this->scrollTo(index);
 }
@@ -450,31 +412,10 @@ void AbstractWheelWidget::paintEvent(QPaintEvent *event)
                     }
                 }
 
-                // QRect第二个参数-50用于item向上偏移
-                paintItem(&painter, itemNum, QRect(6, h / 2 + i * iH - m_itemOffset - iH / 2 - 50, w - 6, iH));
+                paintItem(&painter, itemNum, QRect(6, h / 2 + i * iH - m_itemOffset - iH / 2 + 12, w - 6, iH));
             }
         }
     }
-    /*
-        // draw a transparent bar over the center
-        QColor highlight = palette.color(colorGroup, QPalette::Highlight);
-        highlight.setAlpha(150);
-
-        QLinearGradient grad2(0.5, 0, 0.5, 1.0);
-        grad2.setColorAt(0, highlight);
-        grad2.setColorAt(1.0, highlight.lighter());
-        grad2.setCoordinateMode( QGradient::ObjectBoundingMode );
-        QBrush gBrush2( grad2 );
-
-        QLinearGradient grad3(0.5, 0, 0.5, 1.0);
-        grad3.setColorAt(0, highlight);
-        grad3.setColorAt(1.0, highlight.darker());
-        grad3.setCoordinateMode( QGradient::ObjectBoundingMode );
-        QBrush gBrush3( grad3 );
-
-        painter.fillRect( QRect( 0, h/2 - iH/2, w, iH/2 ), gBrush2 );
-        painter.fillRect( QRect( 0, h/2,        w, iH/2 ), gBrush3 );
-    */
 }
 
 /*!
