@@ -43,32 +43,32 @@
 <context>
     <name>CloseConfirmDialog</name>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="56"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="57"/>
         <source>Exit</source>
         <translation>Kilépés</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="51"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="52"/>
         <source>Minimize to system tray</source>
         <translation>Kicsinyítés a rendszer tálcára</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="61"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="62"/>
         <source>Do not ask again</source>
         <translation>Ne kérdezze újra</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="69"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="70"/>
         <source>Please choose your action</source>
         <translation>Válasszon műveletet</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="82"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="83"/>
         <source>Cancel</source>
         <translation>Mégsem</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="83"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="84"/>
         <source>Confirm</source>
         <translation>Megerősítés</translation>
     </message>
@@ -76,16 +76,16 @@
 <context>
     <name>DBOperate</name>
     <message>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="136"/>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="172"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="139"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="177"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="81"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="82"/>
         <source>Unknown album</source>
         <translation>Ismeretlen Album</translation>
     </message>
     <message>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="139"/>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="175"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="142"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="180"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="77"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="78"/>
         <source>Unknown artist</source>
@@ -402,113 +402,118 @@
 <context>
     <name>MainFrame</name>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="311"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="264"/>
         <source>Add playlist</source>
         <translation>Lejátszási lista létrehozása</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="150"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="313"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="475"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="118"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="266"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="416"/>
         <source>Add music</source>
         <translation>Zeneszám hozzáadása</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="314"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="267"/>
         <source>Equalizer</source>
         <translation>Hangszínszabályzó</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="317"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="270"/>
         <source>Settings</source>
         <translation>Beállítások</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="320"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="273"/>
         <source>Dark theme</source>
         <translation>Sötét téma</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="324"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="379"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="277"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="332"/>
         <source>Exit</source>
         <translation>Kilépés</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="121"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="130"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="138"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="391"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="89"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="98"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="106"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="344"/>
         <source>Music</source>
         <translation>Zene</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="122"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="90"/>
         <source>Music is a local music player with beautiful design and simple functions.</source>
         <translation>A Zene egy zenelejátszó csodaszép dizájnnal és egyszerű funkciókkal.</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="155"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="123"/>
         <source>Select</source>
         <translation>Kiválasztás</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="156"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="124"/>
         <source>Select All</source>
         <translation>Összes kijelölése</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="157"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="125"/>
         <source>Done</source>
         <translation>Kész</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="373"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="326"/>
         <source>Play/Pause</source>
         <translation>Lejátszás/Szünet</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="375"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="328"/>
         <source>Previous</source>
         <translation>Előző</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="377"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="330"/>
         <source>Next</source>
         <translation>Következő</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="573"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="514"/>
         <source>Successfully added to &quot;%1&quot;</source>
         <translation>Sikeres hozzáadás ehhez: &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="576"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="517"/>
         <source>Already added to the playlist</source>
         <translation>Már hozzáadva a lejátszási listához</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="579"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="520"/>
         <source>1 song added</source>
         <translation>1 dal hozzáadva</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="581"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="522"/>
         <source>%1 songs added</source>
         <translation>%1 dal hozzáadva</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="585"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="526"/>
         <source>A disc is connected</source>
         <translation>A lemez csatlakoztatva</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="727"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="576"/>
+        <source>Unsupported audio codec</source>
+        <translation>Nem támogatott audió kodek</translation>
+    </message>
+    <message>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="697"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="720"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="690"/>
         <source>Import failed, no valid music file found</source>
         <translation>Az importálás sikertelen, nem található érvényes zenefájl</translation>
     </message>
@@ -558,59 +563,59 @@
     <name>MusicListDataWidget</name>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="115"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1044"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1065"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1084"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1099"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1030"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1051"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1070"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1085"/>
         <source>No songs</source>
         <translation>Nincsenek dalok</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="979"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="965"/>
         <source>Custom</source>
         <translation>Egyéni</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1046"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1032"/>
         <source>1 album - 1 song</source>
         <translation>1 album - 1 dal</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1049"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1035"/>
         <source>%1 album - %2 songs</source>
         <translation>%1 album - %2 dal</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1051"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1037"/>
         <source>%1 albums - %2 songs</source>
         <translation>%1 album - %2 dal</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1067"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1053"/>
         <source>1 artist - 1 song</source>
         <translation>1 előadó - 1 dal</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1070"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1056"/>
         <source>%1 artist - %2 songs</source>
         <translation>%1 előadó - %2 dal</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1072"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1058"/>
         <source>%1 artists - %2 songs</source>
         <translation>%1 előadó - %2 dal</translation>
     </message>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="117"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1086"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1101"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1072"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1087"/>
         <source>1 song</source>
         <translation>1 dal</translation>
     </message>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="119"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1088"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1103"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1074"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1089"/>
         <source>%1 songs</source>
         <translation>%1 dal</translation>
     </message>
@@ -620,13 +625,13 @@
         <translation>Keresési eredmények</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1003"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="989"/>
         <source>No search results</source>
         <translation>Nincs keresési eredmény</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="865"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="888"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="851"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="874"/>
         <source>All Music</source>
         <translation>Összes zene</translation>
     </message>
@@ -636,35 +641,35 @@
         <translation>CD lejátszási lista</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="933"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="948"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="963"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="980"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="919"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="934"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="949"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="966"/>
         <source>Time added</source>
         <translation>Hozzáadási idő</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="934"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="966"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="983"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="920"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="952"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="969"/>
         <source>Album</source>
         <translation>Album</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="949"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="965"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="982"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="935"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="951"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="968"/>
         <source>Artist</source>
         <translation>Előadó</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="964"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="981"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="950"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="967"/>
         <source>Title</source>
         <translation>Cím</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="839"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="830"/>
         <source>Play All</source>
         <translation>Összes lejátszása</translation>
     </message>
@@ -693,68 +698,68 @@
 <context>
     <name>MusicSongListView</name>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="202"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="450"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="207"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="455"/>
         <source>Pause</source>
         <translation>Szüneteltetés</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="205"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="446"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="210"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="451"/>
         <source>Play</source>
         <translation>Lejátszás</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="211"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="448"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="216"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="453"/>
         <source>Add music</source>
         <translation>Zene hozzáadása</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="212"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="452"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="217"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="457"/>
         <source>Rename</source>
         <translation>Átnevezés</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="213"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="334"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="454"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="218"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="339"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="459"/>
         <source>Delete</source>
         <translation>Törlés</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="296"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="301"/>
         <source>CD playlist</source>
         <translation>CD lejátszási lista</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="326"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="331"/>
         <source>Are you sure you want to delete this playlist?</source>
         <translation>Biztos, hogy törölni akarja ezt a lejátszási listát?</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="333"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="338"/>
         <source>Cancel</source>
         <translation>Mégsem</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="571"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="576"/>
         <source>The CD has been removed</source>
         <translation>A CD eltávolításra került</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="575"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="580"/>
         <source>Play failed, as the CD has been removed</source>
         <translation>A lejátszás sikertelen, mivel a CD eltávolításra került</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="582"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="587"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="883"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="964"/>
         <source>New playlist</source>
         <translation>Új lejátszási lista</translation>
     </message>
@@ -763,137 +768,137 @@
     <name>PlayListView</name>
     <message>
         <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="488"/>
-        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="835"/>
+        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="839"/>
         <source>Unknown artist</source>
         <translation>Ismeretlen Előadó</translation>
     </message>
     <message>
         <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="500"/>
-        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="847"/>
+        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="851"/>
         <source>Unknown album</source>
         <translation>Ismeretlen Album</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1299"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1855"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1291"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1864"/>
         <source>Play queue</source>
         <translation>Lejátszási sor</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1302"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1852"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1294"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1861"/>
         <source>My favorites</source>
         <translation>Kedvenceim</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="580"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="581"/>
         <source>File is invalid or does not exist, load failed</source>
         <translation>Fájl érvénytelen vagy nem létezik, a betöltés sikertelen</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="581"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="582"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1340"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1332"/>
         <source>Play</source>
         <translation>Lejátszás</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1343"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1335"/>
         <source>Pause</source>
         <translation>Szüneteltetés</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1851"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1860"/>
         <source>Add to playlist</source>
         <translation>Hozzáadás a lejátszási listához</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1352"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1344"/>
         <source>Display in file manager</source>
         <translation>Megjelenítés a fájlkezelőben</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1278"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1350"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1416"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1270"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1342"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1408"/>
         <source>Add to</source>
         <translation>Hozzáadás a</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1306"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1298"/>
         <source>Create new playlist</source>
         <translation>Új lejátszási lista létrehozása</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1354"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1418"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1346"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1410"/>
         <source>Remove from play queue</source>
         <translation>Eltávolítás a lejátszási sorból</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1356"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1420"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1348"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1412"/>
         <source>Remove from playlist</source>
         <translation>Éltávoltás a lejátszási listáról </translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1359"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1422"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1351"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1414"/>
         <source>Delete from local disk</source>
         <translation>Törlés a helyi lemezről</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1392"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1384"/>
         <source>Encoding</source>
         <translation>Kódolás</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1396"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1388"/>
         <source>Song info</source>
         <translation>Dal információ</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1114"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1167"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1106"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1159"/>
         <source>Cancel</source>
         <translation>Mégsem</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1115"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1107"/>
         <source>Remove</source>
         <translation>Eltávolítás</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1118"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1110"/>
         <source>Are you sure you want to remove %1?</source>
         <translation>Biztosan el kívánja távolítani a %1-t?</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1120"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1112"/>
         <source>Are you sure you want to remove the selected %1 songs?</source>
         <translation>Biztosan el kívánja távolítani a kijelölt %1 dalokat?</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1168"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1276"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1160"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1268"/>
         <source>Delete</source>
         <translation>Törlés</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1173"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1165"/>
         <source>Are you sure you want to delete %1?</source>
         <translation>Biztos, hogy törölni akarja a %1-t?</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1180"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1172"/>
         <source>Are you sure you want to delete the selected %1 songs?</source>
         <translation>Biztos, hogy törölni akarja a kiválasztott %1 dalokat?</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1181"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1173"/>
         <source>The song files contained will also be deleted</source>
         <translation>A dalfájlok is törlődnek</translation>
     </message>
@@ -901,12 +906,12 @@
 <context>
     <name>PlayQueueWidget</name>
     <message>
-        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="70"/>
+        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="71"/>
         <source>Play Queue</source>
         <translation>Lejátszási sor</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="83"/>
+        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="84"/>
         <source>Empty</source>
         <translation>Ürítés</translation>
     </message>
@@ -930,8 +935,8 @@
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="124"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="128"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="92"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="96"/>
         <source>Music</source>
         <translation>Zene</translation>
     </message>
@@ -1197,7 +1202,7 @@
         <translation>Összes lejátszása</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/subsonglistwidget.cpp" line="109"/>
+        <location filename="../src/music-player/mainFrame/subsonglistwidget.cpp" line="108"/>
         <source>Shuffle</source>
         <translation>Véletlenszerű lejátszás</translation>
     </message>
